@@ -29,7 +29,7 @@ t_RBRACE = r'}'
 t_COMMA = r','
 t_NEWLINE = r'\n'
 t_EQUAL = r'='
-t_ignore = r' \t'
+t_ignore = r' '
 t_LARRAY_BRACE = r'\['
 t_RARRAY_BRACE = r'\]'
 
