@@ -11,10 +11,10 @@ class Grammar:
 
     def __init__(self, production_rules: List[ProductionRule]):
         for pr in production_rules:
-            if pr.source.name.lower() == 'init':
+            if pr.source.name.lower() == 'parser':
                 break
         else:
-            raise Exception('NO_INIT', 'Missing INIT production rule')
+            raise Exception('NO_PARSER', 'Missing parser production rule')
 
         self.production_rules = production_rules
         self.lookup_table = {}
